==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_hr.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=hr
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_ajouter_document' => 'Dodati dokument',
	'bouton_ajouter_image' => 'Dodati sliku',
	'bouton_ajouter_image_document' => 'Dodati sliku ili dokument',

	// E
	'entree_dimensions' => 'Veličina:',
	'entree_titre_document' => 'Naslov dokumenta:',
	'entree_titre_image' => 'Naslov slike:',

	// I
	'image_tourner_180' => 'okrenuti za 180°',
	'image_tourner_droite' => 'okrenuti za 90° nadesno',
	'image_tourner_gauche' => 'okrenuti za 90° nalijevo',
	'info_document' => 'dokument',
	'info_document_indisponible' => 'Ovaj dokument ne stoji na raspolaganju',
	'info_documents' => 'dokumenti',
	'info_inclusion_directe' => 'direktno uključenje:',
	'info_inclusion_vignette' => 'obuhvatiti malu sličicu:',
	'info_installer_tous_documents' => 'Instalirati sve dokumente',
	'info_logo_max_taille' => 'Veličina logotipa smije biti najviše @maxi@ (ova datoteka je veličine @actuel@).',
	'info_portfolio' => 'mapa',
	'info_telecharger' => 'otprema sa Vašeg računala:',
	'item_autoriser_selectionner_date_en_ligne' => 'Pouvoir sélectionner la date de mise en ligne de chaque document', # MODIF
	'item_non_autoriser_selectionner_date_en_ligne' => 'Ne pas pouvoir changer manuellement la date des documents', # MODIF

	// T
	'texte_documents_joints' => 'You can allow the addition of documents (office files, images,
 multimedia, etc.) to articles and/or sections. These files
 could then be referenced in
 the article or displayed separately.', # MODIF

	// U
	'upload_fichier_zip' => 'ZIP datoteka',
	'upload_fichier_zip_texte' => 'Datoteka koju želite instalirati je ZIP-datoteka.',
	'upload_fichier_zip_texte2' => 'datoteka može biti:',
	'upload_limit' => 'Datoteka je prevelika za poslužitelja; maksimalna dozvoljena veličina za <i>otpremu</i> (upload) je @max@.',
	'upload_zip_decompacter' => 'dekomprimirana i sve sadržane datoteke će biti instalirane na web sajtu. Ovo su datoteke koje će biti instalirane:',
	'upload_zip_telquel' => 'instalirana takva kakva jeste (kao ZIP datoteka);'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_hr.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=hr
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_ajouter_document' => 'Dodati dokument',
	'bouton_ajouter_image' => 'Dodati sliku',
	'bouton_ajouter_image_document' => 'Dodati sliku ili dokument',

	// E
	'entree_dimensions' => 'Veličina:',
	'entree_titre_document' => 'Naslov dokumenta:',
	'entree_titre_image' => 'Naslov slike:',

	// I
	'image_tourner_180' => 'okrenuti za 180°',
	'image_tourner_droite' => 'okrenuti za 90° nadesno',
	'image_tourner_gauche' => 'okrenuti za 90° nalijevo',
	'info_document' => 'dokument',
	'info_document_indisponible' => 'Ovaj dokument ne stoji na raspolaganju',
	'info_documents' => 'dokumenti',
	'info_inclusion_directe' => 'direktno uključenje:',
	'info_inclusion_vignette' => 'obuhvatiti malu sličicu:',
	'info_installer_tous_documents' => 'Instalirati sve dokumente',
	'info_logo_max_taille' => 'Veličina logotipa smije biti najviše @maxi@ (ova datoteka je veličine @actuel@).',
	'info_portfolio' => 'mapa',
	'info_telecharger' => 'otprema sa Vašeg računala:',
	'item_autoriser_selectionner_date_en_ligne' => 'Pouvoir sélectionner la date de mise en ligne de chaque document', # MODIF
	'item_non_autoriser_selectionner_date_en_ligne' => 'Ne pas pouvoir changer manuellement la date des documents', # MODIF

	// T
	'texte_documents_joints' => 'You can allow the addition of documents (office files, images,
 multimedia, etc.) to articles and/or sections. These files
 could then be referenced in
 the article or displayed separately.', # MODIF

	// U
	'upload_fichier_zip' => 'ZIP datoteka',
	'upload_fichier_zip_texte' => 'Datoteka koju želite instalirati je ZIP-datoteka.',
	'upload_fichier_zip_texte2' => 'datoteka može biti:',
	'upload_limit' => 'Datoteka je prevelika za poslužitelja; maksimalna dozvoljena veličina za <i>otpremu</i> (upload) je @max@.',
	'upload_zip_decompacter' => 'dekomprimirana i sve sadržane datoteke će biti instalirane na web sajtu. Ovo su datoteke koje će biti instalirane:',
	'upload_zip_telquel' => 'instalirana takva kakva jeste (kao ZIP datoteka);',
];
